@@ -1,4 +1,3 @@
-
 #' @param authInfo Typically an object created by `accountInfo()` augmented
 #'   with the `certificate` from the corresponding `serverInfo()`.
 #'
@@ -8,15 +7,17 @@
 #'   * `apiKey`: set in `connectApiUser()`
 #'
 #' @noRd
-httpRequest <- function(service,
-                        authInfo,
-                        method,
-                        path,
-                        query,
-                        headers = list(),
-                        timeout = NULL,
-                        error_call = caller_env()) {
-
+httpRequest <- function(
+  service,
+  authInfo,
+  method,
+  path,
+  query,
+  headers = list(),
+  timeout = NULL,
+  rawResponse = FALSE,
+  error_call = caller_env()
+) {
   storeCookies(service, httpCookies())
   path <- buildPath(service$path, path, query)
   headers <- c(headers, authHeaders(authInfo, method, path), httpHeaders())
@@ -49,19 +50,26 @@ httpRequest <- function(service,
     )
   }
 
-  handleResponse(httpResponse, error_call = error_call)
+  handleResponse(
+    httpResponse,
+    rawResponse = rawResponse,
+    error_call = error_call
+  )
 }
 
-httpRequestWithBody <- function(service,
-                                authInfo,
-                                method,
-                                path,
-                                query = NULL,
-                                contentType = NULL,
-                                file = NULL,
-                                content = NULL,
-                                headers = list(),
-                                error_call = caller_env()) {
+httpRequestWithBody <- function(
+  service,
+  authInfo,
+  method,
+  path,
+  query = NULL,
+  contentType = NULL,
+  file = NULL,
+  content = NULL,
+  headers = list(),
+  rawResponse = FALSE,
+  error_call = caller_env()
+) {
   if ((is.null(file) && is.null(content))) {
     stop("You must specify either the file or content parameter.")
   }
@@ -112,7 +120,11 @@ httpRequestWithBody <- function(service,
     httpResponse
   }
 
-  handleResponse(httpResponse, error_call = error_call)
+  handleResponse(
+    httpResponse,
+    rawResponse = rawResponse,
+    error_call = error_call
+  )
 }
 
 isRedirect <- function(status) {
@@ -128,18 +140,28 @@ redirectService <- function(service, location) {
   }
 }
 
-handleResponse <- function(response, error_call = caller_env()) {
+handleResponse <- function(
+  response,
+  rawResponse = FALSE,
+  error_call = caller_env()
+) {
   url <- buildHttpUrl(response$req)
   reportError <- function(msg) {
-
+    # msg may be JSON; wrapping with "{msg}" avoids treating it as a formatting string.
     cli::cli_abort(
-      c("<{url}> failed with HTTP status {response$status}", msg),
+      c("<{url}> failed with HTTP status {response$status}", "{msg}"),
       class = c(paste0("rsconnect_http_", response$status), "rsconnect_http"),
       call = error_call
     )
   }
 
-  if (isContentType(response$contentType, "application/json")) {
+  if (rawResponse) {
+    if (response$status %in% 200:399) {
+      out <- response$content
+    } else {
+      reportError(response$content)
+    }
+  } else if (isContentType(response$contentType, "application/json")) {
     # parse json responses
     if (nzchar(response$content)) {
       json <- jsonlite::fromJSON(response$content, simplifyVector = FALSE)
@@ -188,57 +210,95 @@ handleResponse <- function(response, error_call = caller_env()) {
 
 # Wrappers for HTTP methods -----------------------------------------------
 
-GET <- function(service,
-                authInfo,
-                path,
-                query = NULL,
-                headers = list(),
-                timeout = NULL) {
-  httpRequest(service, authInfo, "GET", path, query, headers, timeout)
+GET <- function(
+  service,
+  authInfo,
+  path,
+  query = NULL,
+  headers = list(),
+  timeout = NULL,
+  rawResponse = FALSE
+) {
+  httpRequest(
+    service,
+    authInfo,
+    "GET",
+    path,
+    query,
+    headers,
+    timeout,
+    rawResponse
+  )
 }
 
-DELETE <- function(service,
-                   authInfo,
-                   path,
-                   query = NULL,
-                   headers = list()) {
-  httpRequest(service, authInfo, "DELETE", path, query, headers)
+DELETE <- function(
+  service,
+  authInfo,
+  path,
+  query = NULL,
+  headers = list(),
+  rawResponse = FALSE
+) {
+  httpRequest(
+    service,
+    authInfo,
+    "DELETE",
+    path,
+    query,
+    headers,
+    rawResponse = rawResponse
+  )
 }
 
-POST <- function(service,
-                 authInfo,
-                 path,
-                 query = NULL,
-                 contentType = NULL,
-                 file = NULL,
-                 content = NULL,
-                 headers = list()) {
+POST <- function(
+  service,
+  authInfo,
+  path,
+  query = NULL,
+  contentType = NULL,
+  file = NULL,
+  content = NULL,
+  headers = list(),
+  rawResponse = FALSE
+) {
   # check if the request needs a body
   if ((is.null(file) && is.null(content))) {
     # no file or content, don't include a body with the request
-    httpRequest(service, authInfo, "POST", path, query, headers)
+    httpRequest(
+      service,
+      authInfo,
+      "POST",
+      path,
+      query,
+      headers,
+      rawResponse = rawResponse
+    )
   } else {
     # include the request's data in the body
     httpRequestWithBody(
-    service = service,
-    authInfo = authInfo,
-    method = "POST",
-    path = path,
-    query = query,
-    contentType = contentType,
-    file = file,
-    content = content,
-    headers = headers
+      service = service,
+      authInfo = authInfo,
+      method = "POST",
+      path = path,
+      query = query,
+      contentType = contentType,
+      file = file,
+      content = content,
+      headers = headers,
+      rawResponse = rawResponse
     )
   }
 }
 
-POST_JSON <- function(service,
-                      authInfo,
-                      path,
-                      json,
-                      query = NULL,
-                      headers = list()) {
+POST_JSON <- function(
+  service,
+  authInfo,
+  path,
+  json,
+  query = NULL,
+  headers = list(),
+  rawResponse = FALSE
+) {
   POST(
     service = service,
     authInfo = authInfo,
@@ -246,18 +306,22 @@ POST_JSON <- function(service,
     query = query,
     contentType = "application/json",
     content = toJSON(json),
-    headers = headers
+    headers = headers,
+    rawResponse = rawResponse
   )
 }
 
-PUT <- function(service,
-                authInfo,
-                path,
-                query = NULL,
-                contentType = NULL,
-                file = NULL,
-                content = NULL,
-                headers = list()) {
+PUT <- function(
+  service,
+  authInfo,
+  path,
+  query = NULL,
+  contentType = NULL,
+  file = NULL,
+  content = NULL,
+  headers = list(),
+  rawResponse = FALSE
+) {
   httpRequestWithBody(
     service = service,
     authInfo = authInfo,
@@ -267,16 +331,20 @@ PUT <- function(service,
     contentType = contentType,
     file = file,
     content = content,
-    headers = headers
+    headers = headers,
+    rawResponse = rawResponse
   )
 }
 
-PUT_JSON <- function(service,
-                     authInfo,
-                     path,
-                     json,
-                     query = NULL,
-                     headers = list()) {
+PUT_JSON <- function(
+  service,
+  authInfo,
+  path,
+  json,
+  query = NULL,
+  headers = list(),
+  rawResponse = FALSE
+) {
   PUT(
     service = service,
     authInfo = authInfo,
@@ -284,18 +352,22 @@ PUT_JSON <- function(service,
     query = query,
     contentType = "application/json",
     content = toJSON(json),
-    headers = headers
+    headers = headers,
+    rawResponse = rawResponse
   )
 }
 
-PATCH <- function(service,
-                  authInfo,
-                  path,
-                  query = NULL,
-                  contentType = NULL,
-                  file = NULL,
-                  content = NULL,
-                  headers = list()) {
+PATCH <- function(
+  service,
+  authInfo,
+  path,
+  query = NULL,
+  contentType = NULL,
+  file = NULL,
+  content = NULL,
+  headers = list(),
+  rawResponse = FALSE
+) {
   httpRequestWithBody(
     service = service,
     authInfo = authInfo,
@@ -305,16 +377,20 @@ PATCH <- function(service,
     contentType = contentType,
     file = file,
     content = content,
-    headers = headers
+    headers = headers,
+    rawResponse = rawResponse
   )
 }
 
-PATCH_JSON <- function(service,
-                       authInfo,
-                       path,
-                       json,
-                       query = NULL,
-                       headers = list()) {
+PATCH_JSON <- function(
+  service,
+  authInfo,
+  path,
+  json,
+  query = NULL,
+  headers = list(),
+  rawResponse = FALSE
+) {
   PATCH(
     service = service,
     authInfo = authInfo,
@@ -322,7 +398,8 @@ PATCH_JSON <- function(service,
     query = query,
     contentType = "application/json",
     content = toJSON(json),
-    headers = headers
+    headers = headers,
+    rawResponse = rawResponse
   )
 }
 
@@ -338,7 +415,13 @@ httpTraceJson <- function() {
 
 httpTrace <- function(method, path, time) {
   if (getOption("rsconnect.http.trace", FALSE)) {
-    cat(method, " ", path, " ", as.integer(time[["elapsed"]] * 1000), "ms\n",
+    cat(
+      method,
+      " ",
+      path,
+      " ",
+      as.integer(time[["elapsed"]] * 1000),
+      "ms\n",
       sep = ""
     )
   }
@@ -378,7 +461,8 @@ httpFunction <- function() {
     httpType
   } else {
     stop(paste(
-      "Invalid http option specified:", httpType,
+      "Invalid http option specified:",
+      httpType,
       ". Valid values are libcurl, rcurl, curl, and internal"
     ))
   }
@@ -460,6 +544,9 @@ authHeaders <- function(authInfo, method, path, file = NULL) {
     signatureHeaders(authInfo, method, path, file)
   } else if (!is.null(authInfo$apiKey)) {
     list(`Authorization` = paste("Key", authInfo$apiKey))
+  } else if (!is.null(authInfo$snowflakeToken)) {
+    # snowflakeauth returns a list of named header values
+    authInfo$snowflakeToken
   } else {
     # The value doesn't actually matter here, but the header needs to be set.
     list(`X-Auth-Token` = "anonymous-access")
@@ -523,7 +610,12 @@ signRequestPrivateKey <- function(private_key, canonicalRequest) {
 
   # use sha1 digest and then sign. digest and PKI avoid using system openssl which
   # can be problematic in strict FIPS environments
-  digested <- digest::digest(charToRaw(canonicalRequest), "sha1", serialize = FALSE, raw = TRUE)
+  digested <- digest::digest(
+    charToRaw(canonicalRequest),
+    "sha1",
+    serialize = FALSE,
+    raw = TRUE
+  )
   rawsig <- PKI::PKI.sign(key = pki_key, digest = digested)
   openssl::base64_encode(rawsig)
 }
@@ -608,7 +700,8 @@ readHttpResponse <- function(request, conn) {
   } else {
     # we know the content length, so read exactly that many bytes
     content <- rawToChar(readBin(
-      con = conn, what = "raw",
+      con = conn,
+      what = "raw",
       n = contentLength
     ))
   }
