@@ -18,11 +18,13 @@
 #'
 #' }
 #' @seealso [taskLog()]
+#' @note This function works only with shinyapps.io and posit.cloud.
 #' @export
 tasks <- function(account = NULL, server = NULL) {
-
   # resolve account and create connect client
   accountDetails <- accountInfo(account, server)
+  checkCloudServer(accountDetails$server)
+
   client <- clientForAccount(accountDetails)
 
   # list tasks
@@ -55,15 +57,17 @@ tasks <- function(account = NULL, server = NULL) {
 #'
 #' }
 #' @seealso [tasks()]
+#' @note This function works only with shinyapps.io and posit.cloud.
 #' @export
 taskLog <- function(taskId, account = NULL, server = NULL, output = NULL) {
-
   accountDetails <- accountInfo(account, server)
+  checkCloudServer(accountDetails$server)
+
   client <- clientForAccount(accountDetails)
 
   if (identical(output, "stderr")) {
     conn <- stderr()
-  } else{
+  } else {
     conn <- ""
   }
 
@@ -71,12 +75,13 @@ taskLog <- function(taskId, account = NULL, server = NULL, output = NULL) {
   cat(client$getTaskLogs(taskId), file = conn)
 
   # get child tasks
-  tasks <- client$listTasks(accountDetails$accountId,
-                            filters = filterQuery("parent_id", taskId))
+  tasks <- client$listTasks(
+    accountDetails$accountId,
+    filters = filterQuery("parent_id", taskId)
+  )
 
   # get child task logs
   for (task in tasks) {
     taskLog(task["id"], account = account, server = server, output = output)
   }
-
 }
