@@ -1,4 +1,7 @@
 test_that("can snapshot deps with renv", {
+  skip_if_not_installed("foreign")
+  skip_if_not_installed("MASS")
+
   app_dir <- local_temp_app(list(foo.R = "library(foreign); library(MASS)"))
 
   expect_snapshot(pkgs <- bundlePackages(app_dir))
@@ -13,6 +16,9 @@ test_that("can snapshot deps with renv", {
 })
 
 test_that("can snapshot deps with packrat (option)", {
+  skip_if_not_installed("foreign")
+  skip_if_not_installed("MASS")
+
   withr::local_options(rsconnect.packrat = TRUE)
 
   app_dir <- local_temp_app(list(foo.R = "library(foreign); library(MASS)"))
@@ -28,6 +34,9 @@ test_that("can snapshot deps with packrat (option)", {
 })
 
 test_that("can snapshot deps with packrat (env var)", {
+  skip_if_not_installed("foreign")
+  skip_if_not_installed("MASS")
+
   withr::local_envvar(RSCONNECT_PACKRAT = "TRUE")
 
   app_dir <- local_temp_app(list(foo.R = "library(foreign); library(MASS)"))
@@ -43,6 +52,9 @@ test_that("can snapshot deps with packrat (env var)", {
 })
 
 test_that("can capture deps from renv lockfile", {
+  skip_if_not_installed("foreign")
+  skip_if_not_installed("MASS")
+
   withr::local_options(renv.verbose = FALSE)
 
   app_dir <- local_temp_app(list(foo.R = "library(foreign); library(MASS)"))
@@ -60,6 +72,9 @@ test_that("can capture deps from renv lockfile", {
 })
 
 test_that("can capture deps with packrat even when renv lockfile present", {
+  skip_if_not_installed("foreign")
+  skip_if_not_installed("MASS")
+
   withr::local_envvar(RSCONNECT_PACKRAT = "TRUE")
   withr::local_options(renv.verbose = FALSE)
 
@@ -90,11 +105,14 @@ test_that("error if can't find source", {
   })
 
   app_dir <- withr::local_tempdir()
-  writeLines(con = file.path(app_dir, "index.Rmd"), c(
-    "```{r}",
-    "library(shiny)",
-    "```"
-  ))
+  writeLines(
+    con = file.path(app_dir, "index.Rmd"),
+    c(
+      "```{r}",
+      "library(shiny)",
+      "```"
+    )
+  )
 
   expect_snapshot(
     . <- bundlePackages(app_dir),
@@ -135,12 +153,18 @@ test_that("usePackrat prefers the environment variable over the option", {
 })
 
 test_that("package_record works", {
-  latin1Record <- package_record("latin1package", lib_dir = test_path("packages"))
+  latin1Record <- package_record(
+    "latin1package",
+    lib_dir = test_path("packages")
+  )
   expect_equal(latin1Record$Author, "Jens Fröhling")
 
   utf8Record <- package_record("utf8package", lib_dir = test_path("packages"))
   expect_equal(utf8Record$Author, "Jens Fröhling")
 
-  windows1251Record <- package_record("windows1251package", lib_dir = test_path("packages"))
+  windows1251Record <- package_record(
+    "windows1251package",
+    lib_dir = test_path("packages")
+  )
   expect_equal(windows1251Record$Author, "Сергей Брин")
 })
