@@ -12,7 +12,12 @@ test_that("account file returned with server name", {
 
 test_that("account file containing pattern characters found with server name", {
   local_temp_config()
-  registerAccount("complex", "hatter+mad@example.com", 42, apiKey = "hatter-api-key")
+  registerAccount(
+    "complex",
+    "hatter+mad@example.com",
+    42,
+    apiKey = "hatter-api-key"
+  )
 
   # https://github.com/rstudio/rsconnect/issues/620
   expected <- normalizePath(file.path(
@@ -22,3 +27,13 @@ test_that("account file containing pattern characters found with server name", {
   dir <- accountConfigFile("hatter+mad@example.com", server = "complex")
   expect_equal(dir, expected)
 })
+
+test_that("isDocumentPath", {
+  stuff <- local_temp_app(list(
+    "shiny.app/app.R" = c(),
+    "doc/research.Rmd" = c()
+  ))
+  expect_false(isDocumentPath(file.path(stuff, "shiny.app")))
+  expect_false(isDocumentPath(file.path(stuff, "doc")))
+  expect_true(isDocumentPath(file.path(stuff, "doc/research.Rmd")))
+})
